window.Gleam.initSearch([{"doc":"grille_pain","title":"grille_pain","content":"# 🍞 Grille-Pain — The French Toaster\n\n`grille_pain` is a toaster for lustre, and gleam in a more general manner. It\ntries to be both simple to use, and simple to customise to adapt to your use\ncase. Features could be missing, as `grille_pain` is also an experimentation to\nadd support for effect managers for lustre. It can however completely be used\nin your application, even if you&#39;re not using lustre. `grille_pain` will never\nbreaks intentionnally, and will always take care of providing non-breaking minor\nupdates, but you can potentially expect lot of major updates while design of\neffect managers evolve!\n\n[Because a demo is worth thousand words, you can find one directly here.](https://ghivert.github.io/grille-pain/)\n\nIn order to work without disturbing your application, `grille_pain` behaves as\nan independant component on the page. After setup, `grille_pain` registers a\n`&lt;grille_pain&gt;` node in the DOM, and instanciate a Shadow DOM, to make sure\nstyles won&#39;t intervene with yours.\n\nThis package is inspired by [`react-toastify`](https://github.com/fkhadra/react-toastify),\nfor colors and animations.\n\n&gt; [!WARNING]\n&gt; It&#39;s only working for JavaScript target as of now!\n\n## Installation\n\n```sh\ngleam add grille_pain\n```\n\n## Quickstart\n\n```gleam\nimport gleam/pair\nimport grille_pain\nimport grille_pain/lustre/toast\nimport grille_pain/toast/level\nimport lustre\nimport lustre/attribute\nimport lustre/effect\nimport lustre/element/html\nimport lustre/event\nimport sketch/lustre as sketch_lustre\nimport sketch/options as sketch_options\n\npub type Model =\n  Int\n\npub type Msg {\n  DisplayBasicToast(content: String)\n}\n\n\npub fn main() {\n  let assert Ok(_) = grille_pain.simple()\n  let assert Ok(_) =\n    lustre.application(init, update, view)\n    |&gt; lustre.start(&quot;#app&quot;, Nil)\n}\n\nfn init(_flags) {\n  #(0, effect.none())\n}\n\nfn update(model: Model, msg: Msg) {\n  case msg {\n    DisplayBasicToast(content) -&gt;\n      #(model, toast.toast(content))\n  }\n}\n\nfn view(model: Model) {\n  html.div([], [\n    html.button([event.on_click(DisplayBasicToast(&quot;Success&quot;))], [\n      html.text(&quot;Display toast&quot;)\n    ])\n  ])\n}\n```\n\n## Usage\n\nSetup of `grille_pain` is achieved using `grille_pain.simple()` or\n`grille_pain.setup()` and passing diverse options, like the default timeout for\ntoasts. Once setup, if you&#39;re using lustre, you should only take care of\n`grille_pain/lustre/toast` and use them in your update function, while if not\nusing lustre, you can use `grille_pain/toast`. But be careful, this module is\nside-effectful.\n\nDisplaying a toast is as simple as `toast.toast(&quot;Content&quot;)`, or you can build\nyour custom toast. [The documentation is hosted on hex](https://hexdocs.pm/grille_pain).\n\n## Sticky toasts\n\nDisplaying toasts are cool, but sometimes you need to display a toast that is\nalways visible. `grille_pain` got you covered! Simply set `sticky` in your toast\noptions, and your toast will be sticky! What if you want to hide it? `notify` will\nhelp you get the ID of the toast, and `hide` will hide the toast properly!\n\n## Styling\n\nToasts are styled by default, except for fonts. To define a font that suits you,\nyou have to define a font on the `html`, `body` or `grille-pain` node in the DOM.\nFonts will pierce in the Shadow DOM and apply to the toasts!\n\nIf the default appearance of toasts does not please you, you can always style\nthe toasts! To do it, you have multiple CSS variables, that you can set on the\n`grille-pain` node, directly in CSS.\n\nHere, the different options, with their default values.\n\n```css\ngrille-pain {\n  /* Common options for toasts */\n  --grille_pain-width: 320px;                       /* Wrapper size*/\n  --grille_pain-toast-width: 320px;                 /* Toast size */\n  --grille_pain-toast-min-height: 64px;             /* Toast min height */\n  --grille_pain-toast-max-height: 800px;1           /* Toast max height */\n  --grille_pain-toast-border-radius: 6px;           /* Toast border radius */\n\n  /* Color for standard toast */\n  --grille_pain-Standard-background: #ffffff;       /* Background color */\n  --grille_pain-Standard-text-color: #121212;       /* Text color */\n  --grille_pain-Standard-progress-bar: #000000b3;   /* Progress bar color */\n\n  /* Color for info toast */\n  --grille_pain-Info-background: #3498db;           /* Background color */\n  --grille_pain-Info-text-color: #ffffff;           /* Text color */\n  --grille_pain-Info-progress-bar: #ffffffb3;       /* Progress bar color */\n\n  /* Color for warning toast */\n  --grille_pain-Warning-background: #f1c40f;       /* Background color */\n  --grille_pain-Warning-text-color: #ffffff;       /* Text color */\n  --grille_pain-Warning-progress-bar: #ffffffb3;   /* Progress bar color */\n\n  /* Color for error toast */\n  --grille_pain-Error-background: #e74c3c;         /* Background color */\n  --grille_pain-Error-text-color: #ffffff;         /* Text color */\n  --grille_pain-Error-progress-bar: #ffffffb3;     /* Progress bar color */\n\n  /* Color for success toast */\n  --grille_pain-Success-background: #07bc0c;       /* Background color */\n  --grille_pain-Success-text-color: #ffffff;       /* Text color */\n  --grille_pain-Success-progress-bar: #ffffffb3;   /* Progress bar color */\n}\n```\n\n## Contributing\n\nYou love the package and want to improve it? You have a shiny new framework and\nwant to provide an integration with `grille_pain` in this package? Every contribution is\nwelcome! Feel free to open a Pull Request, and let&#39;s discuss about it!\n","url":"index.html"},{"doc":"grille_pain/error","title":"GrillePainError","content":"pub type GrillePainError {\n  SketchError(error.SketchError)\n  LustreError(lustre.Error)\n  ContextError(String)\n}\n\nSketchError(error.SketchError)\n\n\nLustreError(lustre.Error)\n\n\nContextError(String)\n\n\nSynonyms:\ngrille_pain/error.GrillePainError\ngrille_pain/error GrillePainError","url":"grille_pain/error.html#GrillePainError"},{"doc":"grille_pain/error","title":"context","content":"pub fn context(\n  res: Result(a, b),\n  context: String,\n) -&gt; Result(a, GrillePainError)\n\nSynonyms:\ngrille_pain/error.context\ngrille_pain/error context","url":"grille_pain/error.html#context"},{"doc":"grille_pain/error","title":"lustre","content":"pub fn lustre(\n  res: Result(a, Error),\n) -&gt; Result(a, GrillePainError)\n\nSynonyms:\ngrille_pain/error.lustre\ngrille_pain/error lustre","url":"grille_pain/error.html#lustre"},{"doc":"grille_pain/error","title":"sketch","content":"pub fn sketch(\n  res: Result(a, SketchError),\n) -&gt; Result(a, GrillePainError)\n\nSynonyms:\ngrille_pain/error.sketch\ngrille_pain/error sketch","url":"grille_pain/error.html#sketch"},{"doc":"grille_pain/error","title":"grille_pain/error","content":"","url":"grille_pain/error.html"},{"doc":"grille_pain/toast/level","title":"Level","content":"pub type Level {\n  Standard\n  Info\n  Warning\n  Error\n  Success\n}\n\nStandard\n\n\nInfo\n\n\nWarning\n\n\nError\n\n\nSuccess\n\n\nSynonyms:\ngrille_pain/toast/level.Level\ngrille_pain/toast/level Level","url":"grille_pain/toast/level.html#Level"},{"doc":"grille_pain/toast/level","title":"to_string","content":"pub fn to_string(level: Level) -&gt; String\n Mainly internal use, `to_string` allows you to get the exact representation\n of the level.\nSynonyms:\ngrille_pain/toast/level.to_string\ngrille_pain/toast/level to_string","url":"grille_pain/toast/level.html#to_string"},{"doc":"grille_pain/toast/level","title":"grille_pain/toast/level","content":" Define the different levels of toasts.\n Like logs, toasts have different levels according to their importance.\n When choosing a level, the toast will use the corresponding theme variables,\n allowing you to override the default styles.","url":"grille_pain/toast/level.html"},{"doc":"grille_pain/options","title":"Options","content":"pub type Options {\n  Options(timeout: Int)\n}\n\nOptions(timeout: Int)\n\n\nSynonyms:\ngrille_pain/options.Options\ngrille_pain/options Options","url":"grille_pain/options.html#Options"},{"doc":"grille_pain/options","title":"default","content":"pub fn default() -&gt; Options\n Default options, 5s seconds of timeout.\nSynonyms:\ngrille_pain/options.default\ngrille_pain/options default","url":"grille_pain/options.html#default"},{"doc":"grille_pain/options","title":"timeout","content":"pub fn timeout(\n  options: Options,\n  milliseconds timeout: Int,\n) -&gt; Options\n Define default timeout for toasts. Must be set in milliseconds.\nSynonyms:\ngrille_pain/options.timeout\ngrille_pain/options timeout","url":"grille_pain/options.html#timeout"},{"doc":"grille_pain/options","title":"grille_pain/options","content":" grille-pain options are made to help you customise the behavior of the\n default toasts when using them.\n You should really only take care of `timeout` right now, `debug` being a\n thing to help grille_pain development.\n\n `Options` are made as Builder, meaning you can chain your options directly\n using the pipe operator. The type is public though, meaning you can build it\n as you prefer.\n\n While there&#39;s nothing apart `timeout` currently, `Options` is made to be\n extensible in an easy way.\n\n ```gleam\n import grille_pain/options\n\n fn custom_options() {\n   options.default()\n   |&gt; options.timeout(milliseconds: 5000)\n }\n ```","url":"grille_pain/options.html"},{"doc":"grille_pain","title":"setup","content":"pub fn setup(\n  opts: Options,\n) -&gt; Result(fn(Action(Msg, ClientSpa)) -&gt; Nil, GrillePainError)\n Setup a new `grille_pain` instance. You should not instanciate two instances\n on the page, as `grille_pain` expect to run as a singleton.\n Use `grille_pain/options` to provide and customise options.\nSynonyms:\ngrille_pain.setup\ngrille_pain setup","url":"grille_pain.html#setup"},{"doc":"grille_pain","title":"simple","content":"pub fn simple() -&gt; Result(\n  fn(Action(Msg, ClientSpa)) -&gt; Nil,\n  GrillePainError,\n)\n Setup a new `grille_pain` instance. You should not instanciate two instances\n on the page, as `grille_pain` expect to run as a singleton.\n Setup with default settings, meaning 5s of timeout.\nSynonyms:\ngrille_pain.simple\ngrille_pain simple","url":"grille_pain.html#simple"},{"doc":"grille_pain","title":"grille_pain","content":" `grille_pain` provides a simili effect manager to display and manage your\n toasts. You should instanciate at most one grille-pain on your applications.\n\n This package exposes two entrypoints: `simple` and `setup`. The first one\n should be appropriated for most use-cases. Reach for the next one if you\n really need to customise options.","url":"grille_pain.html"},{"doc":"grille_pain/toast","title":"Options","content":"pub opaque type Options\n Options type allow to modify timeout or level at the notification level\n directly. This is used to create custom toasts and override defaults.\n If you don&#39;t need custom toasts, you should head up to default functions\n (`toast`, `info`, `success`, `error` and `warning`).\n\n It follows the Builder pattern.\n\n \n import grille_pain/toast\n import grille_pain/toast/level\n\n fn custom_toast() {\n   toast.options()\n   |&gt; toast.timeout(milliseconds: 30_000)\n   |&gt; toast.level(level.Warning)\n   |&gt; toast.custom(&quot;Oops&quot;)\n }\n \n\nSynonyms:\ngrille_pain/toast.Options\ngrille_pain/toast Options","url":"grille_pain/toast.html#Options"},{"doc":"grille_pain/toast","title":"custom","content":"pub fn custom(options: Options, content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.custom\ngrille_pain/toast custom","url":"grille_pain/toast.html#custom"},{"doc":"grille_pain/toast","title":"error","content":"pub fn error(content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.error\ngrille_pain/toast error","url":"grille_pain/toast.html#error"},{"doc":"grille_pain/toast","title":"hide","content":"pub fn hide(id: String) -&gt; Nil\n Hide toast. Sticky toast can only be hidden using `hide`.\nSynonyms:\ngrille_pain/toast.hide\ngrille_pain/toast hide","url":"grille_pain/toast.html#hide"},{"doc":"grille_pain/toast","title":"info","content":"pub fn info(content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.info\ngrille_pain/toast info","url":"grille_pain/toast.html#info"},{"doc":"grille_pain/toast","title":"level","content":"pub fn level(options: Options, level: Level) -&gt; Options\n Level of your toast.\nSynonyms:\ngrille_pain/toast.level\ngrille_pain/toast level","url":"grille_pain/toast.html#level"},{"doc":"grille_pain/toast","title":"options","content":"pub fn options() -&gt; Options\n Default, empty options. Use it to start Builder.\nSynonyms:\ngrille_pain/toast.options\ngrille_pain/toast options","url":"grille_pain/toast.html#options"},{"doc":"grille_pain/toast","title":"sticky","content":"pub fn sticky(options: Options) -&gt; Options\n Activate stickiness for toasts. A sticky toast will never go away while it&#39;s\n not hidden manually.\nSynonyms:\ngrille_pain/toast.sticky\ngrille_pain/toast sticky","url":"grille_pain/toast.html#sticky"},{"doc":"grille_pain/toast","title":"success","content":"pub fn success(content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.success\ngrille_pain/toast success","url":"grille_pain/toast.html#success"},{"doc":"grille_pain/toast","title":"timeout","content":"pub fn timeout(\n  options: Options,\n  milliseconds timeout: Int,\n) -&gt; Options\n Timeout to override defaults. Accepts a timeout in milliseconds.\nSynonyms:\ngrille_pain/toast.timeout\ngrille_pain/toast timeout","url":"grille_pain/toast.html#timeout"},{"doc":"grille_pain/toast","title":"toast","content":"pub fn toast(content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.toast\ngrille_pain/toast toast","url":"grille_pain/toast.html#toast"},{"doc":"grille_pain/toast","title":"warning","content":"pub fn warning(content: String) -&gt; String\n\nSynonyms:\ngrille_pain/toast.warning\ngrille_pain/toast warning","url":"grille_pain/toast.html#warning"},{"doc":"grille_pain/toast","title":"grille_pain/toast","content":" `grille_pain/toast` defines the different side-effects to use to display\n toasts. They should be used when your outside of lustre applications. Otherwise\n you should [head up to `grille_pain/lustre/toast`](/grille_pain/grille_pain/lustre/toast.html).","url":"grille_pain/toast.html"},{"doc":"grille_pain/lustre/toast","title":"Options","content":"pub type Options(msg) {\n  Options(\n    timeout: option.Option(Int),\n    level: option.Option(level.Level),\n    sticky: Bool,\n    msg: option.Option(fn(String) -&gt; msg),\n  )\n}\n Options type allow to modify timeout or level at the notification level\n directly. This is used to create custom toasts and override defaults.\n If you don&#39;t need custom toasts, you should head up to default functions\n (`toast`, `info`, `success`, `error` and `warning`).\n\n It follows the Builder pattern.\n\n \n import grille_pain/toast\n import grille_pain/toast/level\n\n fn custom_toast() {\n   toast.options()\n   |&gt; toast.timeout(millisecond1s: 30_000)\n   |&gt; toast.level(level.Warning)\n   |&gt; toast.custom(&quot;Oops&quot;)\n }\n \nOptions(\n  timeout: option.Option(Int),\n  level: option.Option(level.Level),\n  sticky: Bool,\n  msg: option.Option(fn(String) -&gt; msg),\n)\n\n\nSynonyms:\ngrille_pain/lustre/toast.Options\ngrille_pain/lustre/toast Options","url":"grille_pain/lustre/toast.html#Options"},{"doc":"grille_pain/lustre/toast","title":"custom","content":"pub fn custom(options: Options(a), content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.custom\ngrille_pain/lustre/toast custom","url":"grille_pain/lustre/toast.html#custom"},{"doc":"grille_pain/lustre/toast","title":"error","content":"pub fn error(content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.error\ngrille_pain/lustre/toast error","url":"grille_pain/lustre/toast.html#error"},{"doc":"grille_pain/lustre/toast","title":"hide","content":"pub fn hide(id: String) -&gt; Effect(a)\n Hide toast. Sticky toast can only be hidden using `hide`.\nSynonyms:\ngrille_pain/lustre/toast.hide\ngrille_pain/lustre/toast hide","url":"grille_pain/lustre/toast.html#hide"},{"doc":"grille_pain/lustre/toast","title":"info","content":"pub fn info(content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.info\ngrille_pain/lustre/toast info","url":"grille_pain/lustre/toast.html#info"},{"doc":"grille_pain/lustre/toast","title":"level","content":"pub fn level(options: Options(a), level: Level) -&gt; Options(a)\n Level of your toast.\nSynonyms:\ngrille_pain/lustre/toast.level\ngrille_pain/lustre/toast level","url":"grille_pain/lustre/toast.html#level"},{"doc":"grille_pain/lustre/toast","title":"notify","content":"pub fn notify(\n  options: Options(a),\n  msg: fn(String) -&gt; b,\n) -&gt; Options(b)\n\nSynonyms:\ngrille_pain/lustre/toast.notify\ngrille_pain/lustre/toast notify","url":"grille_pain/lustre/toast.html#notify"},{"doc":"grille_pain/lustre/toast","title":"options","content":"pub fn options() -&gt; Options(a)\n Default, empty options. Use it to start Builder.\nSynonyms:\ngrille_pain/lustre/toast.options\ngrille_pain/lustre/toast options","url":"grille_pain/lustre/toast.html#options"},{"doc":"grille_pain/lustre/toast","title":"sticky","content":"pub fn sticky(options: Options(a)) -&gt; Options(a)\n Activate stickiness for toast. A sticky toast will never go away while it&#39;s\n not hidden manually.\nSynonyms:\ngrille_pain/lustre/toast.sticky\ngrille_pain/lustre/toast sticky","url":"grille_pain/lustre/toast.html#sticky"},{"doc":"grille_pain/lustre/toast","title":"success","content":"pub fn success(content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.success\ngrille_pain/lustre/toast success","url":"grille_pain/lustre/toast.html#success"},{"doc":"grille_pain/lustre/toast","title":"timeout","content":"pub fn timeout(\n  options: Options(a),\n  milliseconds timeout: Int,\n) -&gt; Options(a)\n Timeout to override defaults. Accepts a timeout in milliseconds.\nSynonyms:\ngrille_pain/lustre/toast.timeout\ngrille_pain/lustre/toast timeout","url":"grille_pain/lustre/toast.html#timeout"},{"doc":"grille_pain/lustre/toast","title":"toast","content":"pub fn toast(content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.toast\ngrille_pain/lustre/toast toast","url":"grille_pain/lustre/toast.html#toast"},{"doc":"grille_pain/lustre/toast","title":"warning","content":"pub fn warning(content: String) -&gt; Effect(a)\n\nSynonyms:\ngrille_pain/lustre/toast.warning\ngrille_pain/lustre/toast warning","url":"grille_pain/lustre/toast.html#warning"},{"doc":"grille_pain/lustre/toast","title":"grille_pain/lustre/toast","content":" `grille_pain/lustre/toast` defines the different effects to use to display\n toasts with lustre.","url":"grille_pain/lustre/toast.html"}]);